@@ -32,6 +32,7 @@ from cognite.client.data_classes import (
 from cognite.client.data_classes.files import FileMetadata
 from cognite.client.data_classes.functions import FunctionCallsFilter, FunctionsStatus
 from cognite.client.exceptions import CogniteAPIError
+from cognite.client.utils._auxiliary import is_unlimited
 from cognite.client.utils._identifier import IdentifierSequence, SingletonIdentifierSequence
 
 if TYPE_CHECKING:
@@ -187,7 +188,7 @@ class FunctionsAPI(APIClient):
             else:
                 break
         else:
-            raise IOError("Could not retrieve file from files API")
+            raise OSError("Could not retrieve file from files API")
 
         url = "/functions"
         function: Dict[str, Any] = {
@@ -272,7 +273,7 @@ class FunctionsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> functions_list = c.functions.list()
         """
-        if limit in [float("inf"), -1, None]:
+        if is_unlimited(limit):
             limit = LIST_LIMIT_CEILING
 
         filter = FunctionFilter(
@@ -634,7 +635,7 @@ def _validate_function_handle(function_handle: Callable[..., Any]) -> None:
     if not function_handle.__code__.co_name == "handle":
         raise TypeError("Function referenced by function_handle must be named handle.")
     if not set(function_handle.__code__.co_varnames[: function_handle.__code__.co_argcount]).issubset(
-        set(["data", "client", "secrets", "function_call_info"])
+        {"data", "client", "secrets", "function_call_info"}
     ):
         raise TypeError(
             "Arguments to function referenced by function_handle must be a subset of (data, client, secrets, function_call_info)"
@@ -979,7 +980,7 @@ class FunctionSchedulesAPI(APIClient):
             except ValueError:
                 raise AssertionError("Only function_id or function_external_id allowed when listing schedules.")
 
-        if limit in [float("inf"), -1, None]:
+        if is_unlimited(limit):
             limit = LIST_LIMIT_CEILING
 
         filter = FunctionSchedulesFilter(
